# ENHSP Unified Planning integrator 

## Installation
After cloning this repository run ```pip install up-enhsp/```. 

ENHSP will be downloaded and compiled directory from the public repository of ENHSP.
ENHSP, and therefore this integrator requires openjdk 17 installed on your machine.

The installation has been tested in Ubuntu 20.04.3 LTS and in MACOS Monterey 12.1

### Features:
- One shot planning
- Default configuration: Greedy Best First Search as search algorithm + Mrp heuristic with/without helpful actions/transitions


